/* 
 * (c) 2014 - 2020 Juan Balderas
 * This file is part of Dibuja.

 * Dibuja is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Dibuja is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Dibuja.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib/gi18n.h>
#include "dibuja.h"
#include "help.h"
#include "util.h"


void help_show_htm(GtkWidget *menu, gpointer data)
{
	GError *error = NULL;
	gboolean ret = FALSE;

	ret = gtk_show_uri(gtk_widget_get_screen (gtk_widget_get_toplevel(menu)),
						DIBUJA_HELP_URI,
						gtk_get_current_event_time(),
                		&error);
// debug
	g_message("[%s: %d] gtk_show_uri() returned %d, looking for help file \"%s\"\n",
			__FILE__, __LINE__, ret, DIBUJA_HELP_URI);
	if(NULL != error){
		message_box_error(_("Error opening the help file. %s") , error->message);
		g_error_free(error);
	}
	else if(!ret){
		message_box_error(_("Error opening the help file \"%s\".") , DIBUJA_HELP_URI);
	}
}

void help_about_dialog_activate(GtkWidget *menu, gpointer data)
{
	gchar *authors[2] = {"Juan Balderas", NULL};
	gchar license[] = 
	"Dibuja\n"
	"\n"
	"This program is free software: you can redistribute it and/or modify\n"
	"it under the terms of the GNU General Public License as published by\n"
	"the Free Software Foundation, either version 3 of the License, or\n"
	"(at your option) any later version.\n"
	"\n"
	"This program is distributed in the hope that it will be useful,\n"
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
	"GNU General Public License for more details.\n"
	"\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with this program.  If not, see <http://www.gnu.org/licenses/>.";

	char copy_right[] = "(c) " COPY_YEAR " Juan Balderas ";

	char comments[] =
	N_("Simple to use paint program like classic MS Paint or Paintbrush"
       "for Mac but for Linux");

	gtk_show_about_dialog (GTK_WINDOW(gtk_widget_get_toplevel(menu)),
				"program-name"   ,  "Dibuja" ,
				"copyright"      ,  copy_right,
				"logo-icon-name" ,  "dibuja" ,
				"version"        ,  PACKAGE_VERSION,
				"license"        ,  license,
				"authors"        ,  authors ,
				"title"          ,  _("About Dibuja") ,
				"comments"       , _(comments),
				/* Translator name for credit */
				"translator-credits", _("translator-credits"),
				NULL);
}




